# ICS_IPA

This repo is designed to manage the library functions used for DataMining through mdf data files using the DataSpy product made by Intrepid Control System. The library contains a bunch of File I/O functions in a dll that allow users to parse through mdf data files using their own applications like Python, Excel, Matlab, C# etc. This library of functions is duplicated on Intrepids wireless data server (Wireless NeoVI) allowing users to develop scripts on their PC and then run those scripts on the Wireless Neo VI data server without requiring the data to be downloaded.

### Install Process
This package currently only works on windows computer That contain python 3.6. numpy is a dependency package that is required for this library to operate.

To install simply run the following command

```
pip install ICS_IPA
```
